import { ApiOptions } from '../models/ApiOptions';
import { ApiResponse } from '../models/ApiResponse';
import { Criterion } from '../models/Criterion';
import { DataFormat } from '../models/DataFormat';
export declare class JuracusClient {
    private static instance;
    private readonly restClient;
    private readonly websocketClient;
    private readonly connectionId;
    private readonly response;
    private resolveConnectionId?;
    private resolveApiResponse?;
    /**
     * Returns created instance of JuracusClient
     *
     * @param apiKey Key to authorize access to JuracusApi
     */
    static readonly getInstance: (apiKey: string) => JuracusClient;
    /**
     * Creates and configures RestApi and WebsocketApi client with given apiKey as authorization.
     *
     * @param apiKey Key to authorize access to JuracusApi
     */
    private constructor();
    /**
     * Gets called when Websocket message is sent from the server. Executes analysis when ConnectionId is delivered,
     * and completes analysis when done
     *
     * @param event Received message from server in format {@link UpdateMessage}
     */
    private readonly handleWebsocketMessage;
    private readonly maintainWebsocketConnection;
    private readonly createApiResponseFromAxiosError;
    private readonly sendConnectionIdRequestOnOpen;
    private readonly createApiResponseFromConversionError;
    /**
     * Analyze given data with JuracusAI
     *
     * @param criteria   {@link Collection} of criteria to analyze.
     * @param dataFormat Format of the provided file data.
     * @param encodedData       Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @return response  Response as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFromCriteria: (dataFormat: DataFormat, encodedData: string, criteria: readonly Criterion[]) => Promise<ApiResponse>;
    /**
     * Analyze given data with JuracusAI
     *
     * @param tasks      {@link Map} containing the criteria to analyze together with their {@link ApiOptions}.
     * @param dataFormat Format of the provided file data.
     * @param encodedData Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @return response  Result as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFullSpecification: (dataFormat: DataFormat, encodedData: string, tasks: Map<Criterion, ApiOptions>) => Promise<ApiResponse>;
    /**
     * Analyze given data with JuracusAI
     *
     * @param criteria       {@link Collection} of criteria to analyze.
     * @param defaultOptions {@link ApiOptions} default options to use for each analyzed criterion.
     * @param dataFormat     Format of the provided file data.
     * @param encodedData           Data of the file to analyze. You can find the supported file types here: {@link DataFormat}.
     * @return response  Result as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFromCriteriaWithOptions: (dataFormat: DataFormat, encodedData: string, criteria: readonly Criterion[], defaultOptions: ApiOptions) => Promise<ApiResponse>;
}
